{% extends "base.html" %}

{% block title %}Password tool{% endblock %}

{% block content %}

<h1>Password tool</h1>

<p>Create a password hash for use in your plugin configuration:</p>

{% if hashed_password %}
    <p style="font-family: 'Courier New', Courier, monospace; padding: 1em; border: 2px dotted black; margin: 1em 0">{{ hashed_password }}</p>
{% endif %}

<form action="/-/password-tool" method="post">
    <div>
        <input type="text" name="password" style="width: 40%">
        <input type="hidden" name="csrftoken" value="{{ csrftoken() }}">
        <input type="submit" value="Create password hash">
    </div>
</form>

{% endblock %}
